#!groovy

def podYaml (Map config) {
    def output = """
---
apiVersion: v1
kind: Pod
metadata:
  name: ${config.templateName}
spec:
  containers:
"""
    if (config.kaniko == true) {
        output += """
  - name: kaniko
    imagePullPolicy: Always
    image: ${config.repo}/library/kaniko:latest
    tty: true
    command:
    - /busybox/sh
"""
    }
    if (config.alpine == true) {
        output += """
  - name: alpine
    imagePullPolicy: Always
    image: ${config.repo}/library/alpine:latest
    tty: true
"""
    }
    if (config.fedora == true) {
        output += """
  - name: fedora
    imagePullPolicy: Always
    image: ${config.repo}/dockerhub/library/fedora:latest
    tty: true
"""
    }
    return output
}

def deletePod (Map config) {
    def ws = pwd()
    stage ("Delete Pod") {
        container ("alpine") {
            sh """
                apk add --no-cache curl
                curl -L --silent https://nexus.c.test-chamber-13.lan/repository/google-k8s/\$(curl -s https://nexus.c.test-chamber-13.lan/repository/google-k8s/stable.txt)/bin/linux/amd64/kubectl -o /usr/local/bin/kubectl
                chmod +x /usr/local/bin/kubectl
            """

            withKubeConfig ([
                credentialsId: config.kubeAuth,
                serverUrl: config.kubeURL,
                namespace: config.namespace
            ]) {
                sh "for i in \$(kubectl get pods --selector ${config.selector} -o name); do kubectl delete \${i}; done"
            }
        }
    }
}

def buildContainer (Map config, List buildArg = []) {
    def ws = pwd()
    stage ("Build Container") {
        container ("kaniko") {
            writeFile (file: ws + "/Dockerfile", text: config.dockerFile)
            withCredentials([usernameColonPassword(
                credentialsId: config.repoCreds,
                variable: "dCreds"
            )]) {
                sh "set +x; printf '{\"auths\":{\"%s\":{\"auth\": \"%s\"}}}' \"${config.repository}\" \"${dcreds.bytes.encodeBase64().toString()}\" > /kaniko/.docker/config.json"
            }
            def buildArguments = ""
            for (i in buildArg) {
                buildArguments += " --build-arg ${i}"
            }
            sh """
                /kaniko/executor \\
                    --context "${ws}" \\
                    -f "${ws}/Dockerfile" \\
                    --destination "${config.imageDest}" \\
                    ${buildArguments}
            """
        }
    }
}

def pushArtifact (Map config) {
    def ws = pwd()
    stage ("Push Artifact") {
        container ("alpine") {
            sh "apk add --no-cache curl"
            withCredentials([usernameColonPassword(
                credentialsId: config.repoCreds,
                variable: "aCreds"
            )]) {
                sh 'curl --request PUT --user "$aCreds" --upload-file "' + config.fileName + '" "' + config.filePath + '"'
            }
        }
    }
}